@@ -10,7 +10,7 @@ from time import time, sleep
 from logging import getLogger
 from binascii import a2b_hex
 from threading import Thread, current_thread, RLock, Event
-from nem_ed25519 import Encrypt
+from nem_ed25519_rust import generate_keypair, encrypt, decrypt
 from p2p_python.tool.traffic import Traffic
 from p2p_python.tool.utils import AESCipher
 from p2p_python.config import C, V, Debug, PeerToPeerError
@@ -249,19 +249,19 @@ class Core:
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
             # 公開鍵を受取る
-            ecc = Encrypt.new(None)
+            my_sec, my_pub = generate_keypair()
             receive = sock.recv(self.buffsize)
             self.traffic.put_traffic_down(receive)
             other_pk = json.loads(receive.decode())['public-key']
-            ecc.other_pk = a2b_hex(other_pk)
+            other_pub = a2b_hex(other_pk)
             # 公開鍵を送る
-            send = json.dumps({'public-key': ecc.pk}).encode()
+            send = json.dumps({'public-key': my_pub.hex()}).encode()
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
             # AESKEYとヘッダーを取得し復号化する
             receive = sock.recv(self.buffsize)
             self.traffic.put_traffic_down(receive)
-            data = json.loads(ecc.decrypt(receive).decode())
+            data = json.loads(decrypt(my_sec, other_pub, receive).decode())
             aeskey, header = data['aes-key'], data['header']
             log.debug("Success ase-key receive {}".format(host_port))
             # ユーザーを作成する
@@ -395,8 +395,8 @@ class Core:
             if new_user.name == V.SERVER_NAME:
                 raise ConnectionAbortedError('Same origin connection.')
             # こちらの公開鍵を送る
-            ecc = Encrypt.new(None)
-            send = json.dumps({'public-key': ecc.pk}).encode()
+            my_sec, my_pub = generate_keypair()
+            send = json.dumps({'public-key': my_pub.hex()}).encode()
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
             # 公開鍵を取得する
@@ -405,10 +405,10 @@ class Core:
             if len(receive) == 0:
                 raise ConnectionAbortedError('received msg is zero.')
             other_pk = json.loads(receive.decode())['public-key']
-            ecc.other_pk = a2b_hex(other_pk)
+            other_pub = a2b_hex(other_pk)
             # AESKEYとHeaderを暗号化して送る
             send = json.dumps({'aes-key': new_user.aeskey, 'header': self.get_server_header()})
-            encrypted = ecc.encrypt(send.encode())
+            encrypted = encrypt(my_sec, other_pub, send.encode())
             sock.send(encrypted)
             self.traffic.put_traffic_up(encrypted)
             # Accept信号を受け取る
