@@ -5,6 +5,7 @@ import os
 
 # For AES
 from Cryptodome.Cipher import AES
+from Cryptodome.Util.Padding import pad, unpad
 from Cryptodome import Random
 from base64 import b64encode, b64decode
 
@@ -12,6 +13,7 @@ log = getLogger('p2p-python')
 
 
 class EventIgnition:
+
     def __init__(self):
         self.event = dict()
 
@@ -38,6 +40,7 @@ class EventIgnition:
 
 
 class AESCipher:
+
     @staticmethod
     def create_key():
         return b64encode(os.urandom(AES.block_size)).decode()
@@ -53,7 +56,7 @@ class AESCipher:
     def encrypt(key, raw):
         assert type(raw) == bytes, "input data is bytes"
         key = b64decode(key.encode())
-        raw = AESCipher._pad(raw)
+        raw = pad(raw, AES.block_size)
         iv = Random.new().read(AES.block_size)
         cipher = AES.new(key, AES.MODE_CBC, iv)
         return iv + cipher.encrypt(raw)
@@ -64,23 +67,15 @@ class AESCipher:
         key = b64decode(key.encode())
         iv = enc[:AES.block_size]
         cipher = AES.new(key, AES.MODE_CBC, iv)
-        raw = AESCipher._unpad(cipher.decrypt(enc[AES.block_size:]))
+        raw = cipher.decrypt(enc[AES.block_size:])
+        raw = unpad(raw, AES.block_size)
         if len(raw) == 0:
             raise ValueError("AES decryption error, not correct key.")
         return raw
 
-    @staticmethod
-    def _pad(s):
-        pad = AES.block_size - len(s) % AES.block_size
-        add = AES.block_size - len(s) % AES.block_size
-        return s + add * pad.to_bytes(1, 'big')
-
-    @staticmethod
-    def _unpad(s):
-        return s[:-ord(s[len(s) - 1:])]
-
 
 class Peers:
+
     def __init__(self, path):
         """recode all node, don't remove"""
         self._peer = dict()  # {(host, port): header,..}
@@ -115,7 +110,7 @@ class Peers:
             dump((host_port, data), fp)
 
     def cleanup(self):
-        time_limit = int(time() - 3600 * 24 * 30)
+        time_limit = int(time() - 3600*24*30)
         try:
             with open(self.path, mode='br') as fp:
                 for k, v in stream_unpacker(fp):
